%%This script samples the positions of cohesin rings in an .out files
%%and calculates the radius of the rings over time and returns the
%%average radius of gyration of all cohesin rings per time point. This
%%assumes that the cohesin rings of the beads are labeled with the color 5,
%%which is the default color scheme from chromoShake_make_spindle.cpp.

% [FileName, PathName] = uigetfile('*.out','Pick a file');
function [Rg_cohesin] = radiusOfGyration_cohesinRings(FileName)
n = 0;
c = 1;
t = 1;
% m = 1;
coord_counter = 1;
colorTF = 0; %Toggle off color
xyz_time = 0; %Toggle off time xyz

%Open file
fid = fopen(FileName, 'rt');
if fid == -1
    disp('File open not successful')
    exit
else
    %continue using the file
    
    while feof(fid)==0    %while not at the end of the file
        aline = fgetl(fid);  %read through each line
        
        
        %%MassColors File
        if colorTF == 1
            colors(c,1) = str2double(cell2mat({aline}));
            c = c+1;
        end
        
        %locate color files by toggling on and off
        if strncmp(aline,'MassColors',10) == true   %find color files
%             disp('yay');
            colorTF = 1;  %toggle on colors
        end
        
        if colorTF == 1 && strcmp(aline,'') == true  %At the end of color file, toggle off
%             disp('boo');
            colorTF =0;
        end
        
        
        %%Time # file
        if xyz_time==1 && strcmp(aline,'') == true
           
            
            xyz_time = 0;
           
            xyzc_total(:,:,n) = xyzc;
            coord_counter = 1;
            
        end
        if xyz_time == 1 %toggle coordinates on
            xyz(coord_counter,:) = str2num(str2mat(strsplit(aline))).';
            [color_size,~] = size(colors);
            xyzc(coord_counter,:) = horzcat(xyz(coord_counter,:),colors(coord_counter,1));
            coord_counter = (coord_counter + 1);
        end
        
        
        if strncmp(aline,'Time',4)==true %look for time files
            n = n+1;
            Time{t,1} = aline;
            xyz_time = 1;
            t = t+1;
            
        end
        
        
        
        
    end
end
% Need this or the final coordinate set will not get added to xyxc_total
xyzc_total(:,:,n) = xyzc;

%create a matrix containing time
for j = 1:length(Time)
   timeFile(j,1) = str2double(Time{j}(5:end));
end


%%find all coords with a 5's in the fourth Row. The 5's indicate cohesin
%%rings
find_cohesin = sum(ismember(xyzc_total(:,4,1),5)); 
% One cohesin ring is made up of 16 beads. Divide find_cohesin by 16 to
% find the number of cohesin rings
num_Rings = find_cohesin/16;
% Create a matrix that contains only the coords of cohesin rings
cohesin_rings = xyzc_total(1:find_cohesin,1:3,:);


[~, ~, height] = size(cohesin_rings);
%Create a matrix to store all ROGs
indiv_RoG = zeros(num_Rings,1,height);

n = 1;
temp_coords = zeros(16,3);
for k = 1:height
    ring = 1; %the variable ring stores ROGs of all the rings in 1 time-point
    for xcoord = 1:find_cohesin
        
        temp_coords(n,:) = cohesin_rings(xcoord,:,k); %temp_coords stores 16 coords at a time
        n = n+1;
        
        if n == 17
            
            xyzMean = mean(temp_coords); %Calculate the mean of each column of 1 cohesin ring;
            xMean = xyzMean(1,1); %Assign the mean of each column to a variable
            yMean = xyzMean(1,2);
            zMean = xyzMean(1,3);
            
            %calculate the squared residual of the mean for each coord
            xRes = temp_coords(:,1) - xMean;
            yRes = temp_coords(:,2) - yMean;
            zRes = temp_coords(:,3) - zMean;
            
            xyzRes = horzcat(xRes,yRes,zRes);
            xyzResSq = xyzRes.^2;
            
            for i = 1:16
                distance(i) = sqrt(xyzResSq(i,1) + xyzResSq(i,2) + xyzResSq(i,3));
            end
            
            indiv_RoG(ring,1,k) = mean(distance); %indiv_RoG contains RoG of individual cohesin rings
                                                  %(before average)
            ring = ring+1;
            n = 1;
        end
    end
end

%%Return the average RoG of all cohesin rings per time point
Rg_cohesin = mean(indiv_RoG);
%reshape into a column vector of ROGs
Rg_cohesin = reshape(Rg_cohesin,height,1);


plotMatrix = horzcat(timeFile,Rg_cohesin);
save(strcat(FileName,'.mat'));
end