%%This function is designed to parse an .out file and return the radius of
%%gyration over time of all beads labeled with the color 1 (red in
%%chromoView). This function was used to calculate the radius of gyration
%%of a bottlebrush polymer simulation and of a chromatin ring loaded with
%%cohesin rings.

%[FileName, PathName] = uigetfile('*.out','Pick a file');
function [Rg] = radiusOfGyrationBottlebrush(FileName)
n = 0;
c = 1;
t = 1;
% m = 1;
coord_counter = 1;
colorTF = 0; %Toggle off color
xyz_time = 0; %Toggle off time xyz

%Open file
fid = fopen(FileName, 'rt');
if fid == -1
    disp('File open not successful')
    exit
else
    %continue using the file
    
    while feof(fid)==0    %while not at the end of the file
        aline = fgetl(fid);  %read through each line
        
        
        %%MassColors File
        if colorTF == 1
            colors(c,1) = str2double(cell2mat({aline}));
            c = c+1;
        end
        
        %locate color files by toggling on and off
        if strncmp(aline,'MassColors',10) == true   %find color files
%             disp('yay');
            colorTF = 1;  %toggle on colors
        end
        
        if colorTF == 1 && strcmp(aline,'') == true  %At the end of color file, toggle off
%             disp('boo');
            colorTF =0;
        end
        
        
        %%Time # file
        if xyz_time==1 && strcmp(aline,'') == true
           
            
            xyz_time = 0;
           
            xyzc_total(:,:,n) = xyzc;
            coord_counter = 1;
            
        end
        if xyz_time == 1 %toggle coordinates on
            xyz(coord_counter,:) = str2num(str2mat(strsplit(aline))).';
            [color_size,~] = size(colors);
            xyzc(coord_counter,:) = horzcat(xyz(coord_counter,:),colors(coord_counter,1));
            coord_counter = (coord_counter + 1);
        end
        
        
        if strncmp(aline,'Time',4)==true %look for time files
            n = n+1;
            Time{t,1} = aline;
            xyz_time = 1;
            t = t+1;
            
        end
        
        
        
        
    end
end
% Need this or the final coordinate set will not get added to xyxc_total
xyzc_total(:,:,n) = xyzc;

%create a matrix containing time
for j = 1:length(Time)
   timeFile(j,1) = str2double(Time{j}(5:end));
end

%%Cleave off all the numbers but 1 to rid Rg calculation of everything but
%%primary axis (all colors but 1, red in chromoView).
%matrix that will have a 1 to mark color cells containing 1, rest is 0
colorRows = ismember(xyzc_total(:,4,1),1); 
%Since all of the rows with 1s are now 1 and the rest are 0
%and all of the numbers that are not 1's will start at the beginning of the file
%we can use the sum of the colorRows to index the xyzc_total matrix
%to remove all of the numbers that are not 1.

% for rows = (colorRows-1):-1:0
%     xyzc_chr(101-rows) = xyzc_total(end-rows);
% end

[length, ~,~] = size(xyzc_total);
xyzc_chr = xyzc_total((length-100):end,:,:);
%%Calculate Radius of Gyration
xyz_coords = xyzc_chr(:,1:3,:); 
[row, col, height] = size(xyz_coords);
distance = zeros(row,height);

for k = 1:height
    xyzMean = mean(xyz_coords); %Calculate the mean of each column;
    xMean = xyzMean(1,1,k); %Assign the mean of each column to a variable
    yMean = xyzMean(1,2,k);
    zMean = xyzMean(1,3,k);
    
    %calculate the squared residual of the mean for each coord
    xRes = xyz_coords(:,1,k) - xMean;
    yRes = xyz_coords(:,2,k) - yMean;
    zRes = xyz_coords(:,3,k) - zMean;
    
    xyzRes = horzcat(xRes,yRes,zRes);
    xyzResSq = xyzRes.^2;
    
    for i = 1:row
        distance(i,k) = sqrt(xyzResSq(i,1) + xyzResSq(i,2) + xyzResSq(i,3));
    end
    
    Rg = mean(distance);
end
Rg = Rg.';
plotMatrix = horzcat(timeFile,Rg);
save(strcat(FileName,'.mat'));
end